## pyenlone

Python3 implementation of enl.one APIs:
- https://v.enl.one
- https://tasks.enl.one (Soon)
- https://status.enl.one (Not very soon, but soon)
For more info: https://wiki.enl.one/doku.php?id=start

To install:
    pip install pyenlone

All methods returns Munches. That only means you access them both as:
- `some_result.some_property`
- `some_result['some_property']`
